@@ -24,6 +24,26 @@ class Banco(models.Model):
         return self.nome
 
 
+class BoletoCarteira(models.Model):
+    id = models.AutoField(db_column="boleto_carteira_id", primary_key=True)
+
+    numero = models.CharField(db_column="boleto_carteira_numero", max_length=32, null=False)
+    nome = models.CharField(db_column="boleto_carteira_nome", max_length=128, null=False)
+    convenio = models.BooleanField(db_column="boleto_carteira_convenio", default=False, null=False)
+    ativo = models.BooleanField(db_column="boleto_carteira_ativo", default=False, null=False)
+
+    banco = models.ForeignKey('configuracao.Banco', db_column="banco_id", related_name='carteiras')
+
+    class Meta:
+        db_table = u"configuracao\".\"tb_boleto_carteira"
+        verbose_name = u'Carteira de boleto'
+        verbose_name_plural = u'Carteiras de boletos'
+        unique_together = (('banco', 'numero', 'convenio'),)
+
+    def __unicode__(self):
+        return self.nome
+
+
 class Parcela(models.Model):
     id = models.AutoField(db_column="pagamento_parcela_id", primary_key=True)
     numero_parcelas = models.IntegerField(db_column="pagamento_parcela_numero_parcelas")
